// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test OM flux conversion
//
#include <iostream>
#include <cmath>
#include "CalCommon.h"
#include "CalServer.h"
#include "OmFluxConverter.h"
#include "Xmm.h"

using namespace std;

int main()
{
	ValueAsymmetricError vain = { 62.6, { 2.84, 2.84 } },
						 vout;

	calServer.setInstrument(Xmm::OM);
        calServer.state()->filter()->set(Xmm::V);
	OmFluxConverter *fc = 0; fc = calServer.getAtom(fc);
	vout = fc->fluxCorrect(vain, 1.038e-2, 1.675e-2, 0., false);
	cout<<vout.value<<" +"<<vout.error.errorPlus<<" -"
            <<vout.error.errorMinus<<endl;

        // Get a degradation correction factor
        double MJD=52000.0;
        double dfac = fc->calcDegradationFactor(MJD);
        cout<<"Degradation factor for V filter at MJD="<<MJD<<" = "
            <<dfac<<endl;
        MJD=58000.0;
        dfac = fc->calcDegradationFactor(MJD);
        cout<<"Degradation factor for V filter at MJD="<<MJD<<" = "
            <<dfac<<endl;

	return 0;
}

