// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the EMOS redistribution retrieval
//
#include <iostream>
#include <cassert>
#include "CalServer.h"
#include "Redistribution.h"
#include "Xmm.h"

using namespace std;

bool isClose(double a, double b)
{
	if (fabs(b) < 5.e-5)
		//	absolute
		return fabs(a) < 5.e-5;
	else
		return fabs(fabs(a)/fabs(b)-1.) < 5.e-5;
}


int main()
{
	//	setup the the Cal server
	const Xmm::Instrument instrument = Xmm::RGS1;
	calServer.setInstrument(instrument);
	calServer.state()->ccd()->set(1);
	calServer.state()->node()->set(RGScam::PRIMARY_NODE);

	//	get the rmf
	CanonicalRedist *rmf = 0; rmf = calServer.getAtom(rmf);
	const BinnedAxis &ebins = rmf->eBins();

	unsigned nChans = ebins.bins();
	cout<<"RMF for intrument: "<<Xmm::toString(instrument)<<endl;
	cout<<"\nbinNr     binLo   binHi    peakChannel\n";
	Spectrum spec(rmf->spectrum(1000.));
	cout<<spec.peakChannel()<<endl;
	double sum = 0.;
	for (unsigned n=0; n<nChans; ++n)
		sum += spec[n];
	cout<<"Normalization of redistribution: "<<sum<<endl;
	assert(isClose(sum, 1.));

	for (unsigned n=0; n<nChans; n +=100) {
		Spectrum spec(rmf->spectrum(n));
		sum += spec[n];

		//	locate peak channel
		unsigned peakChannel = 0;
		double maxVal = -1.;
		unsigned len = spec.size();
		for (unsigned m=0; m<len; ++m)
			if (spec[m] > maxVal) {
				maxVal = spec[m];
				peakChannel = m;
			}

		unsigned rmfRowPeak = spec.peakChannel();
		cout<<n<<" "<<ebins.bin(n).lo()<<" "<<ebins.bin(n).hi()<<" "
			<<peakChannel<<" "<<rmfRowPeak<<" "<<spec[n]<<endl;
		assert(peakChannel == rmfRowPeak);
	}

	return 0;
}







