// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the specQuality access 
//
//	REFERENCES:
//
//	RDS, April 13 2009
//
#include <cmath>
#include <iostream>
#include "CalServer.h"
#include "SpecQualityServer.h"

using namespace std;

int main()
{
	calServer.setInstrument(Xmm::EPN);
	calServer.state()->randomize()->set(false);
	calServer.state()->temperature()->set(293.);
	calServer.state()->temperatureCamera()->set(293);
        //calServer.state()->mode()->set(Xmm::PRIME_FULL_WINDOW);
        calServer.state()->mode()->set(Xmm::FAST_TIMING);

        // Get the server
	SpecQualityServer *ct = 0; ct = calServer.getAtom(ct);

        short ngroups = ct->nGroups();
        vector<short> ranges = ct->ranges();
        cout<<"EPN....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]<<endl;

        float gsmin = ct->gainSlopeMin();
        float gsmax = ct->gainSlopeMax();
        float gomin = ct->gainOffsetMin();
        float gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

        calServer.releaseAtom(ct);

        calServer.setInstrument(Xmm::EMOS2);
        calServer.state()->mode()->set(Xmm::FAST_COMPRESSED);

        ct = calServer.getAtom(ct);

        ngroups = ct->nGroups();
        ranges = ct->ranges();
        cout<<"EMOS2....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]<<endl;

        gsmin = ct->gainSlopeMin();
        gsmax = ct->gainSlopeMax();
        gomin = ct->gainOffsetMin();
        gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

        calServer.releaseAtom(ct);

        calServer.setInstrument(Xmm::RGS1);
        calServer.state()->mode()->set(Xmm::SPECTROSCOPY);
        ct = calServer.getAtom(ct);

        ngroups = ct->nGroups();
        ranges = ct->ranges();
        resolut = ct->resolution();
        cout<<"RGS1....."<<endl;
        cout<<"NGRP: "<<ngroups<<" Range[2]: "<<ranges[1]<<endl;
        cout<<"Resolution: "<<resolut[10]<<' '<<resolut[100]<<endl;

        gsmin = ct->gainSlopeMin();
        gsmax = ct->gainSlopeMax();
        gomin = ct->gainOffsetMin();
        gomax = ct->gainOffsetMax();

        cout<<"GAIN: "<<gsmin<<" "<<gsmax<<" "<<gomin<<" "<<gomax<<endl;

	return 0;
}


